data "openstack_networking_router_v2" "core_router" {
    /*
    The Core Router sits on the management network and 
    connects almost everything together
    */
    name = "${var.competition_name} Core Router"
}

data "openstack_networking_secgroup_v2" "team_secgroup" {
    /*
    We make a security group for each team
    */
    name = format("%s Team %02d Secgroup", var.competition_name, var.team_num)
}

// Team LAN
resource "openstack_networking_network_v2" "team_lan" {
    /*
    Each team gets their own LAN network
    */
    name = format("Team %02d LAN", var.team_num)
    segments {
        physical_network = "physnet1"
        network_type = "vlan"
        segmentation_id = "${var.team_num + 500}"
    }
}

resource "openstack_networking_subnet_v2" "team_lan_subnet" {
    /*
    Here we create the subnet for the team lan
    Change the CIDR, the Gateway, and the Allocation pools to match the IP scheme
    */
    depends_on = [
        openstack_networking_network_v2.team_lan
    ]
    name = format("Team %02d Internal", var.team_num)
    network_id = openstack_networking_network_v2.team_lan.id
    cidr = "10.${var.team_num}.1.0/24"
    gateway_ip = "10.${var.team_num}.1.254"
    ip_version = 4
    allocation_pool {
        start = "10.${var.team_num}.1.200"
        end = "10.${var.team_num}.1.253"
    }
    /*
    The DNS Nameservers in the Management Network
    */
    dns_nameservers = [
        "172.16.0.1",
        "172.16.0.2"
    ]
}

resource "openstack_networking_port_v2" "team_lan_router_port" {
    name = format("Team %02d Router Port", var.team_num)
    network_id = openstack_networking_network_v2.team_lan.id
    fixed_ip {
        subnet_id = openstack_networking_subnet_v2.team_lan_subnet.id
        ip_address = var.router.ip_LAN
    }
    allowed_address_pairs {
        ip_address = "0.0.0.0/0"
    }
}

// Switching Plane
data "openstack_networking_network_v2" "switching_plane" {
    name = "${var.competition_name} Switching Plane"
}

data "openstack_networking_subnet_v2" "switching_plane_subnet" {
    name = "${var.competition_name} Switching Plane Subnet"
}

resource "openstack_networking_port_v2" "switching_plane_router_port" {
    name = format("Team %02d Router Switching Plane Port", var.team_num)
    network_id = data.openstack_networking_network_v2.switching_plane.id
    fixed_ip {
        subnet_id = data.openstack_networking_subnet_v2.switching_plane_subnet.id
        ip_address = var.router.ip_WAN
    }
    allowed_address_pairs {
        ip_address = "0.0.0.0/0"
    }
}

resource "openstack_networking_router_route_v2" "downstream_lan_route" {
    /*
    This creates a static route through the router so that we can have traffic hit the LAN
    */
    depends_on = [
        openstack_compute_instance_v2.team_router
    ]
    router_id = data.openstack_networking_router_v2.core_router.id
    destination_cidr = "10.${var.team_num}.1.0/24"
    next_hop = var.router.ip_WAN
}
